# pygismeteo-base

База для [pygismeteo](https://github.com/monosans/pygismeteo) и [aiopygismeteo](https://github.com/monosans/aiopygismeteo).

## License / Лицензия

[MIT](https://github.com/monosans/pygismeteo-base/blob/main/LICENSE)
